@@ -39,7 +39,7 @@ const sampleConfig = `
   ## The amount of time a file is allowed to sit in the directory before it is picked up.
   ## This time can generally be low but if you choose to have a very large file written to the directory and it's potentially slow,
   ## set this higher so that the plugin will wait until the file is fully copied to the directory.
-  # directory_duration_threshold = "50ms" 
+  # directory_duration_threshold = "50ms"
   #
   ## A list of the only file names to monitor, if necessary. Supports regex. If left blank, all files are ingested.
   # files_to_monitor = ["^.*\.csv"]
@@ -106,7 +106,7 @@ func (monitor *DirectoryMonitor) Description() string {
 	return "Ingests files in a directory and then moves them to a target directory."
 }
 
-func (monitor *DirectoryMonitor) Gather(acc telegraf.Accumulator) error {
+func (monitor *DirectoryMonitor) Gather(_ telegraf.Accumulator) error {
 	// Get all files sitting in the directory.
 	files, err := ioutil.ReadDir(monitor.Directory)
 	if err != nil {
@@ -118,6 +118,7 @@ func (monitor *DirectoryMonitor) Gather(acc telegraf.Accumulator) error {
 
 		// We've been cancelled via Stop().
 		if monitor.context.Err() != nil {
+			//nolint:nilerr // context cancelation is not an error
 			return nil
 		}
 
@@ -130,7 +131,7 @@ func (monitor *DirectoryMonitor) Gather(acc telegraf.Accumulator) error {
 
 		// If file is decaying, process it.
 		if timeThresholdExceeded {
-			monitor.processFile(file, acc)
+			monitor.processFile(file)
 		}
 	}
 
@@ -149,7 +150,7 @@ func (monitor *DirectoryMonitor) Start(acc telegraf.Accumulator) error {
 	// Monitor the files channel and read what they receive.
 	monitor.waitGroup.Add(1)
 	go func() {
-		monitor.Monitor(acc)
+		monitor.Monitor()
 		monitor.waitGroup.Done()
 	}()
 
@@ -164,7 +165,7 @@ func (monitor *DirectoryMonitor) Stop() {
 	monitor.waitGroup.Wait()
 }
 
-func (monitor *DirectoryMonitor) Monitor(acc telegraf.Accumulator) {
+func (monitor *DirectoryMonitor) Monitor() {
 	for filePath := range monitor.filesToProcess {
 		if monitor.context.Err() != nil {
 			return
@@ -182,7 +183,7 @@ func (monitor *DirectoryMonitor) Monitor(acc telegraf.Accumulator) {
 	}
 }
 
-func (monitor *DirectoryMonitor) processFile(file os.FileInfo, acc telegraf.Accumulator) {
+func (monitor *DirectoryMonitor) processFile(file os.FileInfo) {
 	if file.IsDir() {
 		return
 	}
@@ -266,7 +267,9 @@ func (monitor *DirectoryMonitor) parseFile(parser parsers.Parser, reader io.Read
 			firstLine = false
 		}
 
-		monitor.sendMetrics(metrics)
+		if err := monitor.sendMetrics(metrics); err != nil {
+			return err
+		}
 	}
 
 	return nil
@@ -295,13 +298,16 @@ func (monitor *DirectoryMonitor) parseLine(parser parsers.Parser, line []byte, f
 	}
 }
 
-func (monitor *DirectoryMonitor) sendMetrics(metrics []telegraf.Metric) {
+func (monitor *DirectoryMonitor) sendMetrics(metrics []telegraf.Metric) error {
 	// Report the metrics for the file.
 	for _, m := range metrics {
 		// Block until metric can be written.
-		monitor.sem.Acquire(monitor.context, 1)
+		if err := monitor.sem.Acquire(monitor.context, 1); err != nil {
+			return err
+		}
 		monitor.acc.AddTrackingMetricGroup([]telegraf.Metric{m})
 	}
+	return nil
 }
 
 func (monitor *DirectoryMonitor) moveFile(filePath string, directory string) {
@@ -344,7 +350,7 @@ func (monitor *DirectoryMonitor) SetParserFunc(fn parsers.ParserFunc) {
 
 func (monitor *DirectoryMonitor) Init() error {
 	if monitor.Directory == "" || monitor.FinishedDirectory == "" {
-		return errors.New("Missing one of the following required config options: directory, finished_directory.")
+		return errors.New("missing one of the following required config options: directory, finished_directory")
 	}
 
 	if monitor.FileQueueSize <= 0 {
