@@ -12,8 +12,8 @@ import (
 	"time"
 
 	"github.com/influxdata/telegraf"
+	"github.com/influxdata/telegraf/config"
 	"github.com/influxdata/telegraf/filter"
-	"github.com/influxdata/telegraf/internal"
 	"github.com/influxdata/telegraf/plugins/common/tls"
 	"github.com/influxdata/telegraf/plugins/inputs"
 	jsonparser "github.com/influxdata/telegraf/plugins/parsers/json"
@@ -147,19 +147,19 @@ const sampleConfig = `
 // Elasticsearch is a plugin to read stats from one or many Elasticsearch
 // servers.
 type Elasticsearch struct {
-	Local                      bool              `toml:"local"`
-	Servers                    []string          `toml:"servers"`
-	HTTPTimeout                internal.Duration `toml:"http_timeout"`
-	ClusterHealth              bool              `toml:"cluster_health"`
-	ClusterHealthLevel         string            `toml:"cluster_health_level"`
-	ClusterStats               bool              `toml:"cluster_stats"`
-	ClusterStatsOnlyFromMaster bool              `toml:"cluster_stats_only_from_master"`
-	IndicesInclude             []string          `toml:"indices_include"`
-	IndicesLevel               string            `toml:"indices_level"`
-	NodeStats                  []string          `toml:"node_stats"`
-	Username                   string            `toml:"username"`
-	Password                   string            `toml:"password"`
-	NumMostRecentIndices       int               `toml:"num_most_recent_indices"`
+	Local                      bool            `toml:"local"`
+	Servers                    []string        `toml:"servers"`
+	HTTPTimeout                config.Duration `toml:"http_timeout"`
+	ClusterHealth              bool            `toml:"cluster_health"`
+	ClusterHealthLevel         string          `toml:"cluster_health_level"`
+	ClusterStats               bool            `toml:"cluster_stats"`
+	ClusterStatsOnlyFromMaster bool            `toml:"cluster_stats_only_from_master"`
+	IndicesInclude             []string        `toml:"indices_include"`
+	IndicesLevel               string          `toml:"indices_level"`
+	NodeStats                  []string        `toml:"node_stats"`
+	Username                   string          `toml:"username"`
+	Password                   string          `toml:"password"`
+	NumMostRecentIndices       int             `toml:"num_most_recent_indices"`
 
 	tls.ClientConfig
 
@@ -180,7 +180,7 @@ func (i serverInfo) isMaster() bool {
 // NewElasticsearch return a new instance of Elasticsearch
 func NewElasticsearch() *Elasticsearch {
 	return &Elasticsearch{
-		HTTPTimeout:                internal.Duration{Duration: time.Second * 5},
+		HTTPTimeout:                config.Duration(time.Second * 5),
 		ClusterStatsOnlyFromMaster: true,
 		ClusterHealthLevel:         "indices",
 	}
@@ -277,7 +277,6 @@ func (e *Elasticsearch) Gather(acc telegraf.Accumulator) error {
 				e.serverInfoMutex.Lock()
 				e.serverInfo[s] = info
 				e.serverInfoMutex.Unlock()
-
 			}(serv, acc)
 		}
 		wgC.Wait()
@@ -341,12 +340,12 @@ func (e *Elasticsearch) createHTTPClient() (*http.Client, error) {
 		return nil, err
 	}
 	tr := &http.Transport{
-		ResponseHeaderTimeout: e.HTTPTimeout.Duration,
+		ResponseHeaderTimeout: time.Duration(e.HTTPTimeout),
 		TLSClientConfig:       tlsCfg,
 	}
 	client := &http.Client{
 		Transport: tr,
-		Timeout:   e.HTTPTimeout.Duration,
+		Timeout:   time.Duration(e.HTTPTimeout),
 	}
 
 	return client, nil
@@ -559,11 +558,7 @@ func (e *Elasticsearch) gatherIndicesStats(url string, acc telegraf.Accumulator)
 // gatherSortedIndicesStats gathers stats for all indices in no particular order.
 func (e *Elasticsearch) gatherIndividualIndicesStats(indices map[string]indexStat, now time.Time, acc telegraf.Accumulator) error {
 	// Sort indices into buckets based on their configured prefix, if any matches.
-	categorizedIndexNames, err := e.categorizeIndices(indices)
-	if err != nil {
-		return err
-	}
-
+	categorizedIndexNames := e.categorizeIndices(indices)
 	for _, matchingIndices := range categorizedIndexNames {
 		// Establish the number of each category of indices to use. User can configure to use only the latest 'X' amount.
 		indicesCount := len(matchingIndices)
@@ -591,7 +586,7 @@ func (e *Elasticsearch) gatherIndividualIndicesStats(indices map[string]indexSta
 	return nil
 }
 
-func (e *Elasticsearch) categorizeIndices(indices map[string]indexStat) (map[string][]string, error) {
+func (e *Elasticsearch) categorizeIndices(indices map[string]indexStat) map[string][]string {
 	categorizedIndexNames := map[string][]string{}
 
 	// If all indices are configured to be gathered, bucket them all together.
@@ -600,7 +595,7 @@ func (e *Elasticsearch) categorizeIndices(indices map[string]indexStat) (map[str
 			categorizedIndexNames["_all"] = append(categorizedIndexNames["_all"], indexName)
 		}
 
-		return categorizedIndexNames, nil
+		return categorizedIndexNames
 	}
 
 	// Bucket each returned index with its associated configured index (if any match).
@@ -618,7 +613,7 @@ func (e *Elasticsearch) categorizeIndices(indices map[string]indexStat) (map[str
 		categorizedIndexNames[match] = append(categorizedIndexNames[match], indexName)
 	}
 
-	return categorizedIndexNames, nil
+	return categorizedIndexNames
 }
 
 func (e *Elasticsearch) gatherSingleIndexStats(name string, index indexStat, now time.Time, acc telegraf.Accumulator) error {
@@ -640,7 +635,6 @@ func (e *Elasticsearch) gatherSingleIndexStats(name string, index indexStat, now
 	if e.IndicesLevel == "shards" {
 		for shardNumber, shards := range index.Shards {
 			for _, shard := range shards {
-
 				// Get Shard Stats
 				flattened := jsonparser.JSONFlattener{}
 				err := flattened.FullFlattenJSON("", shard, true, true)
